Module producer
queuey_
core
0.2.1
Module producer
Module Items
Structs
In crate queuey_
core
queuey_core
Module
producer
The
Producer
: type-safe publishing into a queue set.
Structs

Producer
Type-safe publisher.
Q
pins the producer to one queue set so a job from a different application cannot be enqueued by accident.